# coding: utf-8

"""
SAML2 Authentication Module

This module provides compatibility for users expecting to import
OneLogin_Saml2_Auth from onelogin.saml2.auth. However, OneLogin_Saml2_Auth is
actually provided by the 'python3-saml' package, not this onelogin package.

This onelogin package is for OneLogin API management, while python3-saml is
for SAML2 authentication integration.
"""
